@@ -52,6 +52,7 @@ class LocationExtent(BaseModel):
 
 
 class BaseLink(BaseElement):
+    collection: str = Field("links", const=True)
     source_uid: str = Field(..., description="UID of source node")
     target_uid: str = Field(..., description="UID of target node")
     vertices: Optional[List[Location]] = Field(
@@ -67,6 +68,7 @@ class BaseLink(BaseElement):
 
 
 class BaseNode(BaseElement):
+    collection: str = Field("nodes", const=True)
     location: Location = Field(..., description="Geographical location")
     schematic_location: Optional[Location] = Field(
         None, description="Schematic location. Takes value of 'location' if unset."
@@ -80,4 +82,4 @@ class BaseNode(BaseElement):
 
 
 class BaseGroup(BaseNode):
-    pass
+    collection: str = Field("groups", const=True)
